@@ -70,7 +70,7 @@ class Exceptions:
 
 class SimpleDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html)
     """
 
@@ -89,7 +89,7 @@ class SimpleDBClient(BaseClient):
         Performs multiple DeleteAttributes operations in a single call, which reduces
         round trips and latencies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#batch_delete_attributes)
         """
 
@@ -100,7 +100,7 @@ class SimpleDBClient(BaseClient):
         The `BatchPutAttributes` operation creates or replaces attributes within one or
         more items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#batch_put_attributes)
         """
 
@@ -108,7 +108,7 @@ class SimpleDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#can_paginate)
         """
 
@@ -116,7 +116,7 @@ class SimpleDBClient(BaseClient):
         """
         The `CreateDomain` operation creates a new domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#create_domain)
         """
 
@@ -125,13 +125,13 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        Attributes: Sequence["AttributeTypeDef"] = None,
-        Expected: "UpdateConditionTypeDef" = None
+        Attributes: Sequence["AttributeTypeDef"] = ...,
+        Expected: "UpdateConditionTypeDef" = ...
     ) -> None:
         """
         Deletes one or more attributes associated with an item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#delete_attributes)
         """
 
@@ -139,7 +139,7 @@ class SimpleDBClient(BaseClient):
         """
         The `DeleteDomain` operation deletes a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#delete_domain)
         """
 
@@ -149,21 +149,21 @@ class SimpleDBClient(BaseClient):
         number of items and attributes in the domain, and the size of the attribute
         names and values.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#domain_metadata)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#generate_presigned_url)
         """
 
@@ -172,23 +172,23 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        AttributeNames: Sequence[str] = None,
-        ConsistentRead: bool = None
+        AttributeNames: Sequence[str] = ...,
+        ConsistentRead: bool = ...
     ) -> GetAttributesResultTypeDef:
         """
         Returns all of the attributes associated with the specified item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.get_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.get_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#get_attributes)
         """
 
     def list_domains(
-        self, *, MaxNumberOfDomains: int = None, NextToken: str = None
+        self, *, MaxNumberOfDomains: int = ..., NextToken: str = ...
     ) -> ListDomainsResultTypeDef:
         """
         The `ListDomains` operation lists all domains associated with the Access Key ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#list_domains)
         """
 
@@ -198,36 +198,36 @@ class SimpleDBClient(BaseClient):
         DomainName: str,
         ItemName: str,
         Attributes: Sequence["ReplaceableAttributeTypeDef"],
-        Expected: "UpdateConditionTypeDef" = None
+        Expected: "UpdateConditionTypeDef" = ...
     ) -> None:
         """
         The PutAttributes operation creates or replaces attributes in an item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.put_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.put_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#put_attributes)
         """
 
     def select(
-        self, *, SelectExpression: str, NextToken: str = None, ConsistentRead: bool = None
+        self, *, SelectExpression: str, NextToken: str = ..., ConsistentRead: bool = ...
     ) -> SelectResultTypeDef:
         """
         The `Select` operation returns a set of attributes for `ItemNames` that match
         the select expression.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Client.select)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Client.select)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/client.html#select)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/paginators.html#listdomainspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["select"]) -> SelectPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/sdb.html#SimpleDB.Paginator.Select)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sdb.html#SimpleDB.Paginator.Select)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/paginators.html#selectpaginator)
         """
