@@ -19,7 +19,7 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListDomainsPaginatorName", "SelectPaginatorName", "ServiceName")
+__all__ = ("ListDomainsPaginatorName", "SelectPaginatorName", "ServiceName", "PaginatorName")
 
 
 ListDomainsPaginatorName = Literal["list_domains"]
@@ -294,10 +294,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -305,3 +307,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_domains", "select"]
